@@ -1,6 +1,6 @@
 var searchData=
 [
-  ['features_20特點_0',['Features 特點',['..//build/opencc/src/OpenCC/README.md#autotoc_md2',1,'']]],
+  ['features_20特點_0',['Features 特點',['..//startdir/src/OpenCC/README.md#autotoc_md2',1,'']]],
   ['filenotfound_1',['FileNotFound',['../classopencc_1_1_file_not_found.html',1,'opencc']]],
   ['filenotwritable_2',['FileNotWritable',['../classopencc_1_1_file_not_writable.html',1,'opencc']]],
   ['findnextinline_3',['FindNextInline',['../classopencc_1_1_u_t_f8_util.html#ada1b68a720e3f667f1eb8dc4f17f00a4',1,'opencc::UTF8Util']]],
